@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <config.h>
 
@@ -799,6 +799,8 @@ x_window_set_current_page (GSCHEM_TOPLEVEL *w_current, PAGE *page)
   g_return_if_fail (toplevel != NULL);
   g_return_if_fail (page != NULL);
 
+  o_redraw_cleanstates (w_current);
+
   s_page_goto (toplevel, page);
 
   i_update_menus (w_current);
