@@ -16,7 +16,7 @@
 |  COPYRIGHT file in the top level directory of this distribution.
 | 
 |  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 
@@ -1253,9 +1253,6 @@ parse_config(gchar *config, gchar *arg)
 	else if (!strcmp(config, "gnetlist"))
 		extra_gnetlist_list =
 				g_list_append(extra_gnetlist_list, g_strdup(arg));
-	else if (!strcmp(config, "gnetlist-arg"))
-		extra_gnetlist_arg_list =
-				g_list_append(extra_gnetlist_arg_list, g_strdup(arg));
 	else if (!strcmp(config, "empty-footprint"))
 		empty_footprint_name = g_strdup(arg);
 	else
@@ -1370,10 +1367,10 @@ static gchar *usage_string1 =
 "   --gnetlist backend    A convenience run of extra gnetlist -g commands.\n"
 "                         Example:  gnetlist partslist3\n"
 "                         Creates:  myproject.partslist3\n"
-"   --gnetlist-arg arg    Allows additional arguments to be passed to gnetlist.\n"
 " --empty-footprint name  See the project.sample file.\n"
 "\n"
 "options (not recognized in a project file):\n"
+"   --gnetlist-arg arg    Allows additional arguments to be passed to gnetlist.\n"
 "       --fix-elements    If a schematic component footprint is not equal\n"
 "                         to its PCB element Description, update the\n"
 "                         Description instead of replacing the element.\n"
@@ -1432,6 +1429,14 @@ get_args(gint argc, gchar **argv)
 				fix_elements = TRUE;
 				continue;
 				}
+			else if (!strcmp(opt, "gnetlist-arg"))
+				{
+				extra_gnetlist_arg_list =
+					g_list_append(extra_gnetlist_arg_list,
+							g_strdup(arg));
+				i++;
+				continue;
+				}
 			else if (!strcmp(opt, "help") || !strcmp(opt, "h"))
 				usage();
 			else if (   i < argc
